- |Efficiency| :class:`linear_model.ElasticNet`, :class:`linear_model.ElasticNetCV`,
  :class:`linear_model.Lasso`, :class:`linear_model.LassoCV`,
  :class:`linear_model.MultiTaskElasticNet`, :class:`linear_model.MultiTaskElasticNetCV`
  :class:`linear_model.MultiTaskLasso`, :class:`linear_model.MultiTaskLassoCV`
  as well as
  :func:`linear_model.lasso_path` and :func:`linear_model.enet_path` are now faster when
  fit with strong L1 penalty and many features. During gap safe screening of features,
  the update of the residual is now only performed if the coefficient is not zero.
  By :user:`Christian Lorentzen <lorentzenchr>`.
